Streaming & Iteration
=====================

.. versionadded:: 19.10.0

.. automodule:: glom.streaming

.. contents:: Contents
   :local:

.. autoclass:: glom.Iter

   .. automethod:: map
   .. automethod:: filter
   .. automethod:: chunked
   .. automethod:: split
   .. automethod:: flatten
   .. automethod:: unique
   .. automethod:: limit
   .. automethod:: slice
   .. automethod:: takewhile
   .. automethod:: dropwhile
   .. automethod:: all
   .. automethod:: first
